<?php

include(dirname(__FILE__) . "/bowob_core.php");

function bowobs_version(){
  return "5_8_14";
}

function bowobs_user_logued(){
  global $user;
  
  if($user->uid > 0){
    return true;
  }
  else{
    return false;
  }
}

function bowobs_user_id(){
  global $user;
  
  return $user->uid;
}

function bowobs_user_name(){
  global $user;

  if($user->uid > 0){
    return $user->name;
  }
  else{
    return "";
  }
}

function bowobs_user_validate($username){
  if($username == ""){
    return 1;
  }
  
  if(drupal_is_denied("user", $username)){
    return 2;
  }
  
  if(db_result(db_query("SELECT COUNT(*) FROM {users} WHERE LOWER(name) = LOWER('%s')", $username)) > 0){
    return 3;
  }
  
  return 0;
}

function bowobs_user_logued_validate(){
  return user_access("bowob chat");
}

function bowobs_redirect_index(){
  drupal_goto("");
}

function bowobs_redirect_login(){
  drupal_goto("user");
}

function bowobs_enable(){
  if(!db_table_exists("bowob")){
    switch($GLOBALS['db_type']){
      case 'pgsql':
        db_query("CREATE TABLE {bowob} (
          id SERIAL,
          sync VARCHAR(50) NOT NULL DEFAULT '',
          time INTEGER NOT NULL DEFAULT 0,
          user VARCHAR(50) NOT NULL DEFAULT '',
          type INTEGER NOT NULL DEFAULT 0,
          CONSTRAINT bowob_pk PRIMARY KEY (id)
        )");
        break;
      default:
        db_query("CREATE TABLE {bowob} (
          id int(10) unsigned NOT NULL auto_increment,
          sync varchar(50) NOT NULL default '',
          time int(10) unsigned NOT NULL default '0',
          user varchar(50) NOT NULL default '',
          type int(10) unsigned NOT NULL default '0',
          PRIMARY KEY  (`id`)
        ) /*!40100 DEFAULT CHARACTER SET UTF8 */");
    }
  }
}

function bowobs_disable(){
  if(db_table_exists("bowob")){
    db_query("DROP TABLE {bowob}");
  }
}

function bowobs_db_insert($sync, $time, $user, $type){
  db_query("INSERT INTO {bowob} (sync, time, user, type) VALUES ('%s', %d, '%s', %d)", $sync, $time, $user, $type);

  $rs = db_fetch_object(db_query("SELECT id FROM {bowob} WHERE sync='%s' AND time=%d", $sync, $time));
  if(!$rs){
    return 0;
  }

  return $rs->id;
}

function bowobs_db_extract($sid, $ssync, $stime){
  db_query("DELETE FROM {bowob} WHERE time < %d", $stime);

  $rs = db_fetch_object(db_query("SELECT sync, user, type FROM {bowob} WHERE id = %d AND sync = '%s'", $sid, $ssync));
  
  if(!$rs || $rs->sync != $ssync){
    return array();
  }
  else{
    db_query("DELETE FROM {bowob} WHERE id = %d", $sid);
    return array($rs->user, $rs->type);
  }
}

function bowobs_menu($may_cache){
  $items = array();

  if($may_cache){
    $items[] = array(
      'path' => 'bowob',
      'title' => t('Chat'),
      'callback' => 'drupal_get_form',
      'callback arguments' => array('bowobs_login'),
      'access' => bowobs_menu_bowob_access(),
      'type' => MENU_CALLBACK
    );
  }

  return $items;
}

function bowobs_menu_bowob_access(){
  global $user, $bowob_chat_onlyreg;
  
  if($bowob_chat_onlyreg && $user->uid){
    return bowobs_user_logued_validate();
  }
  else{
    return true;
  }
}

function bowobs_login(){
  if(isset($_POST["username"])){
    bowobf_loginsubmit($_POST["username"]);
  }
  
  return bowobf_login();
}

function bowobs_login_submit($form_id, $form_values){
  bowobf_loginsubmit($form_values["username"]);
}

function bowobs_block($page, $op, $delta){
  if($op == "list"){
    $blocks[0]["info"] = t("BoWoB Link");
    $blocks[1]["info"] = t("BoWoB Login");

    return $blocks;
  }
  else if($op == "view" && $page != "bowob"){
    $block = array();
    $block["subject"] = t("Chat");
    if($delta == 0){
      $block["content"] = drupal_get_form("bowobf_linkblock");
    }
    else{
      $block["content"] = drupal_get_form("bowobf_loginblock");
    }

    return $block;
  }
}

function bowobs_form_blocklink(){
  $items = array();
  
  $items[] = l(t("Chat"), "bowob", array("title" => t("Chat")));
  $form["links"] = array("#value" => theme("item_list", $items));

  return $form;
}

function bowobs_form_blocklogin(){
  $form = array(
    "#action" => url("bowob"),
    "#id" => "bowob-login-form",
    "#base" => "bowobs_login",
  );

  $form["username"] = array(
    "#type" => "textfield",
    "#title" => t("Username"),
    "#maxlength" => USERNAME_MAX_LENGTH,
    "#size" => 15,
    "#required" => TRUE,
  );

  $form["submit"] = array(
    "#type" => "submit",
    "#value" => t("Chat"),
  );
  
  return $form;
}

function bowobs_form_login(){
  $form = array(
    "#action" => url("bowob"),
    "#id" => "bowob-login-form",
    "#base" => "bowobs_login",
  );

  $form["username"] = array(
    "#type" => "textfield",
    "#weight" => 2,
    "#title" => t("Username"),
    "#maxlength" => USERNAME_MAX_LENGTH,
    "#size" => 60,
    "#required" => TRUE,
    "#description" => t("Enter your @s username.", array("@s" => variable_get("site_name", "Drupal"))),
  );

  $form["submit"] = array(
    "#type" => "submit",
    "#value" => t("Chat"),
    "#weight" => 3,
  );

  return $form;
}

function bowobs_form_error($type, $username){
  if($type == 1){
    form_set_error("username", t("!name field is required.", array("!name" => t("Username"))));
  }
  elseif($type == 2){
    form_set_error("username", t("The name %name is a reserved username.", array("%name" => $username)));
  }
  elseif($type == 3){
    form_set_error("username", t("The name %name is already taken.", array("%name" => $username)));
  }
}

function bowobs_cookie_get($value){
  return $value;
}

?>
